@@ -13,7 +13,7 @@ class SituacoesDePagamento(object):
     pendente = "pending"
     em_andamento = "?"
     rejeitado = "?"
-    devolvido = "?"
+    devolvido = "refunded"
     cancelado = "?"
     em_mediacao = "?"
     charged_back = "?"
@@ -55,19 +55,28 @@ class Registro(RegistroBase):
             return self.dados["referencia"]
         if "paymentrequest_0_invnum" in self.dados:
             return self.dados["paymentrequest_0_invnum"]
+        if "invoice" in self.dados:
+            return self.dados["invoice"]
         return None
 
     @property
     def identificador_id(self):
         return self.dados.get("paymentinfo_0_transactionid", None)
 
+    @property
+    def chave_status(self):
+        if "payment_status" in self.dados:
+            return "payment_status"
+        if "paymentinfo_0_paymentstatus" in self.dados:
+            return "paymentinfo_0_paymentstatus"
+        return None
+
     def __getattr__(self, name):
         if name.startswith("situacao_"):
             tipo = name.replace("situacao_", "")
-            if self.retorno_de_requisicao:
-                return tipo == "situacao_em_andamento"
-            if self.retorno_de_notificacao:
-                return self.dados["paymentinfo_0_paymentstatus"].lower() == SituacoesDePagamento.do_tipo(tipo)
+            if self.chave_status:
+                return self.dados[self.chave_status].lower() == SituacoesDePagamento.do_tipo(tipo)
+            return False
         return object.__getattribute__(self, name)
 
     @property
@@ -90,7 +99,7 @@ class Registro(RegistroBase):
 
     @property
     def alterar_situacao(self):
-        return "paymentinfo_0_paymentstatus" in self.dados
+        return self.chave_status in self.dados
 
     @property
     def grava_identificador(self):
@@ -138,8 +147,6 @@ class Registro(RegistroBase):
             self._valores_de_pagamento["identificador_id"] = retorno["token"].upper()
         if "paymentinfo_0_amt" in retorno:
             self._valores_de_pagamento["valor_pago"] = self.formatador.string_para_decimal(retorno["paymentinfo_0_amt"])
-        if self.retorno_de_notificacao:
-            self.dados.update(retorno)
         return {"content": retorno, "status": 200 if self.sucesso else 500, "reenviar": False}
 
     @property
